@@ -32,8 +32,6 @@
 #ifndef	_MACH_I386__STRUCTS_H_
 #define	_MACH_I386__STRUCTS_H_
 
-#if defined (__i386__) || defined (__x86_64__)
-
 #include <sys/cdefs.h> /* __DARWIN_UNIX03 */
 #include <machine/types.h> /* __uint8_t */
 
@@ -1311,6 +1309,4 @@ _STRUCT_X86_CPMU_STATE64
 };
 #endif /* !__DARWIN_UNIX03 */
 
-#endif /* defined (__i386__) || defined (__x86_64__) */
-
 #endif /* _MACH_I386__STRUCTS_H_ */
\ No newline at end of file
